@@ -60,16 +60,16 @@ AppletPrivate::AppletPrivate(const KPluginMetaData &info, int uniqueID, Applet *
       oldImmutability(Types::Mutable),
       appletDescription(info),
       icon(appletDescription.iconName()),
-      mainConfig(0),
+      mainConfig(nullptr),
       pendingConstraints(Types::NoConstraint),
-      script(0),
-      package(0),
-      configLoader(0),
+      script(nullptr),
+      package(nullptr),
+      configLoader(nullptr),
       actions(AppletPrivate::defaultActions(applet)),
-      activationAction(0),
+      activationAction(nullptr),
       itemStatus(Types::UnknownStatus),
-      modificationsTimer(Q_NULLPTR),
-      deleteNotificationTimer(Q_NULLPTR),
+      modificationsTimer(nullptr),
+      deleteNotificationTimer(nullptr),
       hasConfigurationInterface(false),
       failed(false),
       transient(false),
@@ -105,13 +105,11 @@ AppletPrivate::~AppletPrivate()
     }
 
     delete script;
-    script = 0;
-    delete package;
-    package = 0;
+    script = nullptr;
     delete configLoader;
-    configLoader = 0;
+    configLoader = nullptr;
     delete mainConfig;
-    mainConfig = 0;
+    mainConfig = nullptr;
     delete modificationsTimer;
 }
 
@@ -123,12 +121,12 @@ void AppletPrivate::init(const QString &_packagePath, const QVariantList &args)
 
     QAction *closeApplet = actions->action(QStringLiteral("remove"));
     if (closeApplet) {
-        closeApplet->setText(i18nc("%1 is the name of the applet", "Remove this %1", q->title()));
+        closeApplet->setText(i18nc("%1 is the name of the applet", "Remove %1", q->title()));
     }
 
     QAction *configAction = actions->action(QStringLiteral("configure"));
     if (configAction) {
-        configAction->setText(i18nc("%1 is the name of the applet", "%1 Settings...", q->title().replace(QLatin1Char('&'), QStringLiteral("&&"))));
+        configAction->setText(i18nc("%1 is the name of the applet", "Configure %1...", q->title().replace(QLatin1Char('&'), QStringLiteral("&&"))));
     }
 
     if (!appletDescription.isValid()) {
@@ -147,23 +145,23 @@ void AppletPrivate::init(const QString &_packagePath, const QVariantList &args)
         return;
     }
 
-    const QString packagePath = _packagePath.isEmpty() && !appletDescription.metaDataFileName().isEmpty() ? QFileInfo(appletDescription.metaDataFileName()).dir().path() : _packagePath;
-    QString path = appletDescription.rawData().value(QStringLiteral("X-Plasma-RootPath")).toString();
-    if (path.isEmpty()) {
-        path = packagePath.isEmpty() ? appletDescription.pluginId() : packagePath;
-    }
-    Plasma::Package p = PluginLoader::self()->loadPackage(QStringLiteral("Plasma/Applet"), api);
-    p.setPath(path);
+    //A constructor may have set a valid package already
+    if (!package.isValid()) {
+        const QString packagePath = _packagePath.isEmpty() && !appletDescription.metaDataFileName().isEmpty() ? QFileInfo(appletDescription.metaDataFileName()).dir().path() : _packagePath;
+        QString path = appletDescription.rawData().value(QStringLiteral("X-Plasma-RootPath")).toString();
+        if (path.isEmpty()) {
+            path = packagePath.isEmpty() ? appletDescription.pluginId() : packagePath;
+        }
 
-    package = new KPackage::Package(*p.d->internalPackage);
+        package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Applet"));
+        package.setPath(path);
 
-    if (!package->isValid()) {
-        delete package;
-        package = 0;
-        q->setLaunchErrorMessage(i18nc("Package file, name of the widget",
-                                       "Could not open the %1 package required for the %2 widget.",
-                                       appletDescription.pluginId(), appletDescription.name()));
-        return;
+        if (!package.isValid()) {
+            q->setLaunchErrorMessage(i18nc("Package file, name of the widget",
+                                        "Could not open the %1 package required for the %2 widget.",
+                                        appletDescription.pluginId(), appletDescription.name()));
+            return;
+        }
     }
 
     // now we try and set up the script engine.
@@ -174,13 +172,11 @@ void AppletPrivate::init(const QString &_packagePath, const QVariantList &args)
     //It's valid, let's try to load the icon from within the package
     if (script) {
         //use the absolute path of the in-package icon as icon name
-        if (appletDescription.iconName().startsWith('/')) {
-            icon = package->filePath("", appletDescription.iconName().toUtf8());
+        if (appletDescription.iconName().startsWith(QLatin1Char('/'))) {
+            icon = package.filePath({}, appletDescription.iconName());
         }
     //package not valid, get rid of it
     } else {
-        delete package;
-        package = 0;
         q->setLaunchErrorMessage(
             i18nc("API or programming language the widget was written in, name of the widget",
                   "Could not create a %1 ScriptEngine for the %2 widget.",
@@ -188,10 +184,10 @@ void AppletPrivate::init(const QString &_packagePath, const QVariantList &args)
     }
 
     if (!q->isContainment()) {
-        QAction *a = new QAction(QIcon::fromTheme(QStringLiteral("preferences-desktop-default-applications")), i18n("Alternatives..."), q);
+        QAction *a = new QAction(QIcon::fromTheme(QStringLiteral("widget-alternatives")), i18n("Show Alternatives..."), q);
         a->setVisible(false);
         q->actions()->addAction(QStringLiteral("alternatives"), a);
-        QObject::connect(a, &QAction::triggered,[=] {
+        QObject::connect(a, &QAction::triggered, [this] {
             if (q->containment()) {
                 emit q->containment()->appletAlternativesRequested(q);
             }
@@ -279,7 +275,7 @@ void AppletPrivate::askDestroy()
 
         if (!q->isContainment()) {
             deleteNotification->setTitle(i18n("Widget Removed"));
-            deleteNotification->setText(i18n("The widget \"%1\" has been removed.", q->title()));
+            deleteNotification->setText(i18n("The widget \"%1\" has been removed.", q->title().toHtmlEscaped()));
         } else if (asContainment && (asContainment->containmentType() == Types::PanelContainment || asContainment->containmentType() == Types::CustomPanelContainment)) {
             deleteNotification->setTitle(i18n("Panel Removed"));
             deleteNotification->setText(i18n("A panel has been removed."));
@@ -301,7 +297,7 @@ void AppletPrivate::askDestroy()
                             //when an applet gets transient, it's "systemimmutable"
                             emit q->immutabilityChanged(q->immutability());
                             delete containmentApplet->d->deleteNotificationTimer;
-                            containmentApplet->d->deleteNotificationTimer = 0;
+                            containmentApplet->d->deleteNotificationTimer = nullptr;
                         }
 
                         //make sure the applets are sorted by id
@@ -316,7 +312,7 @@ void AppletPrivate::askDestroy()
                     } else if (deleteNotificationTimer) {
                         deleteNotificationTimer->stop();
                         deleteNotificationTimer->deleteLater();
-                        deleteNotificationTimer = 0;
+                        deleteNotificationTimer = nullptr;
                     }
                 });
         QObject::connect(deleteNotification.data(), &KNotification::closed, q,
@@ -328,7 +324,7 @@ void AppletPrivate::askDestroy()
                     if (deleteNotificationTimer) {
                         deleteNotificationTimer->stop();
                         deleteNotificationTimer->deleteLater();
-                        deleteNotificationTimer = 0;
+                        deleteNotificationTimer = nullptr;
                     }
                 });
 
@@ -461,7 +457,7 @@ void AppletPrivate::setUiReady()
 // package exists and that we have a script engine
 void AppletPrivate::setupPackage()
 {
-    if (!package) {
+    if (!package.isValid()) {
         return;
     }
 
@@ -476,7 +472,7 @@ void AppletPrivate::setupPackage()
     //     KGlobal::dirs()->addResourceDir("locale", translationsPath);
     // }
 
-    if (!package->filePath("mainconfigui").isEmpty()) {
+    if (!package.filePath("mainconfigui").isEmpty()) {
         q->setHasConfigurationInterface(true);
     }
 }
@@ -533,7 +529,7 @@ KConfigGroup *AppletPrivate::mainConfigGroup()
     }
 
     Containment *c = q->containment();
-    Plasma::Applet *parentApplet = 0;
+    Plasma::Applet *parentApplet = nullptr;
     if (c) {
         parentApplet = qobject_cast<Plasma::Applet *>(c->parent());
     }
@@ -588,7 +584,7 @@ void AppletPrivate::resetConfigurationObject()
     mainConfig->deleteEntry("activityId");
     mainConfig->deleteGroup();
     delete mainConfig;
-    mainConfig = 0;
+    mainConfig = nullptr;
 
     Containment *cont = qobject_cast<Containment *>(q);
 
